@@ -1,9 +1,9 @@
-from nepse.market.core import MarketClient
-from typing import  Optional
+from typing import Optional
 
 import httpx
 
-from nepse.utils import ClientWrapperHTTPX
+from nepse.market.core import MarketClient
+from nepse.utils import _ClientWrapperHTTPX
 
 from .security import SecurityClient
 
@@ -16,7 +16,7 @@ class Client:
         cache_retain_time: Optional[int] = 60,
     ) -> None:
         self._session = httpx_client or httpx.AsyncClient()
-        self._client_wrapper = ClientWrapperHTTPX(self._session)
+        self._client_wrapper = _ClientWrapperHTTPX(self._session)
         self._security_client = SecurityClient(
             self._client_wrapper, cache_retain_time, use_cache
         )
@@ -24,11 +24,24 @@ class Client:
 
     @property
     def security_client(self) -> SecurityClient:
+        """Returns the initialized `SecurityClient`
+
+        Returns:
+            SecurityClient: It is the module through which you can interact with
+            API's securities and its data.
+        """
         return self._security_client
 
     @property
     def market_client(self) -> MarketClient:
+        """Returns the initialized `MarketClient`
+
+        Returns:
+            MarketClient: It is the module through which you can interact with
+            NEPSE's Market.
+        """
         return self._market_client
 
     async def close(self) -> None:
+        """Properly disposes the session"""
         await self._session.aclose()
