@@ -1,31 +1,53 @@
-from json import JSONDecodeError
 import json
-from nepse.errors import APIError
+from json import JSONDecodeError
 from operator import attrgetter
 from typing import Any, Iterable, Optional, TypeVar
 
 import attr
 import httpx
 
+from nepse.errors import APIError
+
 T = TypeVar("T")
 
 
 @attr.frozen
-class ClientWrapperHTTPX:
+class _ClientWrapperHTTPX:
     _client: httpx.AsyncClient
 
-    async def get_json(self, url: str) -> object:
+    async def _get_json(self, url: str) -> object:
         try:
             return (await self._client.get(url)).json()
         except JSONDecodeError:
             raise APIError()
 
-    async def post_json(self, url: str, body: dict) -> object:
-        content = json.dumps(body)
-        return (await self._client.post(url, content=content)).json()
+    # Created this cause NEPSE API requires POST request
+    # with `{"id": 678}` in body.
+    async def _post_json_defualt_body(self, url: str) -> object:
+        body = {"id": 678}
+        return (await self._client.post(url, json=body)).json()
+
+    async def _post_json(self, url: str, body: dict) -> object:
+        """[summary]
+
+        Args:
+            url (str): [description]
+            body (dict): [description]
+
+        Returns:
+            object: [description]
+        """
+        return (await self._client.post(url, json=body)).json()
 
 
 def get(iterable: Iterable[T], **attrs: Any) -> Optional[T]:
+    """A helper that returns the first element in the iterable that meets
+    all the traits passed in ``attrs``.
+
+    Args:
+        iterable (Iterable): An iterable to search through.
+        **attrs (Any): Keyword arguments that denote attributes to search with.
+    """
     attrget = attrgetter
 
     # Special case the single element call
